@@ -1,8 +1,8 @@
+from . import decorators
 
 from .email_handler import EmailHandler
 from .file_operations import FileOperations
 from .scraping_engine import Scraper
 from .mongo_engine import MongoEngine
 from .image_processor import ImageHandler, ImgProcessorJS
-from .table_helpers import create_table_from_objects
-from .decorators import decorators, files, logging, profilers
\ No newline at end of file
+from .table_helpers import create_table_from_objects
\ No newline at end of file
